# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

fix-make.pl - Fix common stupid errors in Makefiles

=head1 SYNOPSIS

    perl fix-make.pl < {bad-file}  > {good-file}

=head1 DESCRIPTION

The I<fix-make.pl> command fixes common problems in I<Makefile>s.
These include:

=over 4

=item 1)

Lines that begin with eight spaces instead of a tape.

=item 2)

Lines which end with a backslash (\) followed by spaces.

=back

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut
use strict;
use warnings;

while (1) {
    # The line from the input
    my $line = <STDIN>;
    if (not defined($line)) {
        last;
    }
    chomp $line;

    # Change 8 spaces at the line start to a tab
    $line =~ s/^        /\t/;
    # Remove any spaces or tabs at the end of a \ 
    # ending line
    $line =~ s/\\\s*/\\/;

    print "$line\n";
}
