# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

dump.pl - Dump out a binary file

=head1 SYNOPSIS

    perl dump.pl <file>

=head1 DESCRIPTION

The I<dump.pl> writes out a binary file in hex and character form.

=head1 BUGS

Minimal error checking.

Does not properly handle files who's length is not a multiple
of eight bytes.

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut
use strict;
use warnings;

open IN_FILE, "<$ARGV[0]" or 
    die("Could not $ARGV[0]");

binmode(IN_FILE);
while (1) {
    my $buffer;	# Buffer containing the binary data
    # Read and store the number of bytes read
    my $read_size = read(IN_FILE, $buffer, 8);

    if ($read_size < 8) {
         last;
    }

    # Data as hex
    my @hex = unpack("H2" x 8, $buffer);
    # Data as a character
    my @char = unpack("a1" x 8 ,$buffer);

    # Fix any funny characters
    foreach my $ch (@char)
    {
        if (($ch lt ' ') || ($ch gt "~")) {
            $ch = ".";
        }
    }
    # Print data
    print "@hex: @char\n";
}
