# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

import.pl - Import disks into the database

=head1 SYNOPSIS

    perl import.pl <file> [<file> ...]

=head1 DESCRIPTION

The I<import.pl> reads text files of the form:

    <id>	<description>

Where I<id> is the disk id (such as f24).  This is a category letter
(f) and an disk number (24).   The description is used to describe the 
disk.

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut
#
# Imports a raw text file and produces a database
#
use strict;
use warnings;

use disks;

# The database to add things to
my $db = disks->new("disks.db", 0);

if (not defined($db)) {
    die("Could not open disks.db");
}

# Loop over the input and figure out what's there
while (<>) {
    chomp($_);
    /(.)(\S*)\s*(.*)/;
    my $category = $1;
    my $id = $1.$2;
    my $title = $3;
    $db->update_disk($id, 
	    DESCRIPTION => $title, 
	    CATEGORY => $category);
}
