=pod

=head1 NAME

diff.pl - Check two word lists for differences

=head1 SYNOPSIS

    diff.pl <file1> <file2>

=head1 DESCRIPTION

The I<diff.pl> checks the two word lists and prints out a list
of words that:

=over 4

=item 1.

Appear in the first file, but not the second.

=item 2.

Appear in the second file, but not the first.

=item 3.

Appear in both files.

=back

=head1 EXAMPLES

=head2 File: list1.txt

    alpha
    beta
    gamma
    fred

=head2 File: list2.txt

    joe
    alpha
    beta
    gamma

=head3 Sample run

    $ perl diff.pl list1.txt list2.txt

    Words only in list1.txt
	    fred
    Words only in list2.txt
	    joe
    Words in both list1.txt and list2.txt
	    alpha
	    beta
	    gamma

=cut
use strict;
use warnings;

if ($#ARGV != 1) {
    print STDERR "Usage is $0 <list1> <list2>\n";
    exit (8);
}

my %list = ();	# Key = word, value = 1,2,B depending on 
		# which file the work occurs in

open IN_FILE, "<$ARGV[0]" or
    die("Could not open $ARGV[0]");

while (<IN_FILE>) {
    chomp($_);
    $list{$_} = 1;
}
close (IN_FILE);
#--------------------------------------------
open IN_FILE, "<$ARGV[1]" or
    die("Could not open $ARGV[1]");

while (<IN_FILE>) {
    chomp($_);
    if (defined($list{$_})) {
	$list{$_} = 'B';
    } else {
	$list{$_} = 2;
    }
}
close (IN_FILE);
#--------------------------------------------
print "Words only in $ARGV[0]\n";
foreach my $cur_key (sort keys %list) {
    if ($list{$cur_key} eq 1) {
	print "\t$cur_key\n";
    }
}
#--------------------------------------------
print "Words only in $ARGV[1]\n";
foreach my $cur_key (sort keys %list) {
    if ($list{$cur_key} eq 2) {
	print "\t$cur_key\n";
    }
}
#--------------------------------------------
print "Words in both $ARGV[0] and $ARGV[1]\n";
foreach my $cur_key (sort keys %list) {
    if ($list{$cur_key} eq 'B') {
	print "\t$cur_key\n";
    }
}
