=pod

=head1 NAME

dup.pl - Check one or more directories for duplicate files

=head1 SYNOPSIS

    dup.pl <dir> [<dir> ....]

=head1 DESCRIPTION

The I<dup.pl> scans directories and reports any duplicate files.

=head1 EXAMPLES

To check to see if any files are 
duplicated in /home/oualline/work
requires the command:

        perl dup.pl /home/oualline/work
=cut
use strict;
use warnings;
use File::Find ();
use Digest::MD5;

# A hash keys=checksum values=files
my %file_hash = ();

# Generated by find2html
# for the convenience of &wanted calls, including -eval statements:
use vars qw/*name *dir *prune/;
*name   = *File::Find::name;
*dir    = *File::Find::dir;
*prune  = *File::Find::prune;

########################################################
# process($file) -- process a single file and 
# 	report if it's a duplciate
########################################################
sub process($)
{
    my $file = shift;	# The file to check

    # Checksum object
    my $digest = Digest::MD5->new();

    # Checksum the file
    open IN_FILE, "<$file" or
        die("Could not read $file");
    $digest->addfile(*IN_FILE);
    close(IN_FILE);

    # Get the checksum
    my $checksum = $digest->b64digest();

    # Does a file already exist with this checksum?
    if (defined($file_hash{$checksum})) {
	# Yes -- duplicate
        print "Duplicate:\n";
	print "\t$file_hash{$checksum}\n";
	print "\t$file\n";
    } else {
        # No, store results
        $file_hash{$checksum} = $file;
    }
}

# Generated by find2pl
sub wanted {
    my ($dev,$ino,$mode,$nlink,$uid,$gid);

    (($dev,$ino,$mode,$nlink,$uid,$gid) = lstat($_)) &&
    -f _ &&
    process($name);
}

# Process each directory on the line
File::Find::find({wanted => \&wanted}, @ARGV);

