=pod

=head1 NAME

time_diff.pl - Compute the difference between the clock says and now.

=head1 SYNOPSIS

    time_diff.pl <set-time> <clock-time> <actual-time>

=head1 DESCRIPTION

The I<time_diff.pl> program is designed to be a tool for use
by horologist who need help adjusting their clocks.

The idea is that you set you clock on day 1.  On day 2 you record
the actual time (as given by an accurate clock) and the time
reported by the clock you are adjusting.  

You then feed these values into this program which gives you can
idea of how far you are off as a percentage.  Hopefully you can
use this information to properly adjust your clocks.

=head1 EXAMPLES

We set our clock at noon.  The next day at 11:00 we checked
on it and it said 11:47.  

    $ perl time_diff.pl 12:00 11:47 11:00

    Clock is fast by 47 minutes
    Error rate:  3.41 percent

=head1 NOTES

No matter what you do to a Congreve clock the best you can hope for
is an error rate of 20 minutes a day.

=cut
use strict;
use warnings;

sub decode($)
{
    my $time = shift;
    my @parts = split /:/, $time;

    return ($parts[0] * 60 + $parts[1]);
}
# The number of minutes in a day
my $DAY = (24 * 60);

if ($#ARGV != 2) {
    print "Usage is $0 <set-time> <clock-time> <actual-time>\n";
    exit (8);
}

# Time we set the clock
my $set_time = decode($ARGV[0]);

# Time the clock shows now
my $clock_time = decode($ARGV[1]);

# Real time 
my $actual_time = decode($ARGV[2]);

$clock_time += $DAY;
$actual_time += $DAY;

if ($clock_time < $actual_time) {
    print "Clock is slow by ", $actual_time - $clock_time, " minutes\n";
} elsif ($clock_time > $actual_time) {
    print "Clock is fast by ", $clock_time - $actual_time, " minutes\n";
} else {
    print "Clock is on time!\n";
}

# The difference
my $ratio = ($clock_time - $set_time) / ($actual_time - $set_time);
$ratio = ($ratio - 1.0) * 100.0;
printf "Error rate: %5.2f percent\n", $ratio;

